"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Window | Document | Global mocking
 */
function createNodeMocks(template, additionalWindowMocks, globalNodeMocks) {
    if (additionalWindowMocks === void 0) { additionalWindowMocks = {}; }
    if (globalNodeMocks === void 0) { globalNodeMocks = {}; }
    if (!template && typeof template !== 'string') {
        console.error("\n      A template of your index.html file must be provided.\n      Example:\n        import { createNodeMocks } from '@devhelponline/create-node-mocks';\n        const template = readFileSync(join(DIST_FOLDER, 'Your_CLI_Project_Name', 'index.html')).toString();\n        createNodeMocks(template);\n    ");
        return;
    }
    var domino = require('domino');
    var win = domino.createWindow(template);
    var noop = function () { };
    win.scrollTo = noop;
    win.screen = {};
    win.alert = noop;
    Object.keys(additionalWindowMocks).forEach(function (key) {
        win[key] = additionalWindowMocks[key];
    });
    global['window'] = win;
    global['document'] = win.document;
    global['navigator'] = {};
    global['CSS'] = null;
    global['Prism'] = null;
    global['HTMLElement'] = null;
    Object.keys(globalNodeMocks).forEach(function (key) {
        global[key] = globalNodeMocks[key];
    });
    Object.defineProperty(win.document.body.style, 'transform', {
        value: function () {
            return {
                enumerable: true,
                configurable: true
            };
        }
    });
}
exports.createNodeMocks = createNodeMocks;
//# sourceMappingURL=main.js.map